# generate-license [![NPM version](https://img.shields.io/npm/v/generate-license.svg?style=flat)](https://www.npmjs.com/package/generate-license) [![NPM downloads](https://img.shields.io/npm/dm/generate-license.svg?style=flat)](https://npmjs.org/package/generate-license) [![Build Status](https://img.shields.io/travis/generate/generate-license.svg?style=flat)](https://travis-ci.org/generate/generate-license)

Generate a license file for a GitHub project.

![generate-license demo](https://raw.githubusercontent.com/generate/generate-license/master/demo.gif)

## Table of Contents

- [What is "Generate"?](#what-is-generate)
- [Command line usage](#command-line-usage)
  * [Install](#install)
  * [Run](#run)
  * [Help](#help)
  * [Running tasks](#running-tasks)
- [Available tasks](#available-tasks)
- [API usage](#api-usage)
  * [Install locally](#install-locally)
  * [Use as a plugin](#use-as-a-plugin)
  * [Register as a generator](#register-as-a-generator)
- [Customization](#customization)
  * [Destination directory](#destination-directory)
  * [Overriding templates](#overriding-templates)
- [About](#about)
  * [Related projects](#related-projects)
  * [Contributing](#contributing)
  * [Running tests](#running-tests)
  * [Author](#author)
  * [License](#license)

_(TOC generated by [verb](https://github.com/verbose/verb) using [markdown-toc](https://github.com/jonschlinkert/markdown-toc))_

## What is "Generate"?

Generate is a command line tool and developer framework for scaffolding out new GitHub projects using [generators](https://github.com/generate/generate/blob/master/docs/generators.md) and [tasks](https://github.com/generate/generate/blob/master/docs/tasks.md).

Answers to prompts and the user's environment can be used to determine the templates, directories, files and contents to build. Support for [gulp](http://gulpjs.com), [base](https://github.com/node-base/base) and [assemble](https://github.com/assemble/assemble) plugins, and much more.

**For more information**:

* Visit the [generate project](https://github.com/generate/generate/)
* Visit the [generate documentation](https://github.com/generate/generate/blob/master/docs/)
* Find [generators on npm](https://www.npmjs.com/browse/keyword/generate-generator) (help us [author generators](https://github.com/generate/generate/blob/master/docs/micro-generators.md))

## Command line usage

### Install

**Installing the CLI**

To run the `license` generator from the command line, you'll need to install [Generate](https://github.com/generate/generate) globally first. You can do that now with the following command:

```sh
$ npm install --global generate
```

This adds the `gen` command to your system path, allowing it to be run from any directory.

**Install generate-license**

Install this module with the following command:

```sh
$ npm install --global generate-license
```

### Run

You should now be able to run `generate-license` with the following command:

```sh
$ gen license
```

**What will happen?**

Running `$ gen license` will run the generator's [default task](#default), which will:

1. prompt you to choose a license to generate
2. prompt you for any information that's missing, if applicable (like author name, etc.)
3. render the necessary template(s) using your answers
4. write [the resulting files](#available-tasks) to the current working directory

**What you should see in the terminal**

If completed successfully, you should see both `starting` and `finished` events in the terminal, like the following:

```sh
[00:44:21] starting ...
...
[00:44:22] finished ✔
```

If you do not see one or both of those events, please [let us know about it](../../issues).

### Help

To see a general help menu and available commands for Generate's CLI, run:

```sh
$ gen help
```

### Running tasks

Tasks on `generate-license` are run by passing the name of the task to run after the generator name, delimited by a comma:

```sh
$ gen license:foo
       ^       ^
generator     task
```

**Example**

The following will run generator `foo`, task `bar`:

```sh
$ gen foo:bar
```

**Default task**

When a task name is not explicitly passed on the command line, Generate's CLI will run the [default](#default) task.

## Available tasks

### [agpl-3.0](generator.js#L27)

Generate a GNU Affero General Public License v3.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:agpl-3.0
$ gen license:agpl-3.0 --dest ./docs
$ gen dest license:agpl-3.0
```

### [apache-2.0](generator.js#L44)

Generate an Apache License 2.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:apache-2.0
$ gen license:apache-2.0 --dest ./docs
$ gen dest license:apache-2.0
```

### [artistic-2.0](generator.js#L61)

Generate an Artistic License 2.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:artistic-2.0
$ gen license:artistic-2.0 --dest ./docs
$ gen dest license:artistic-2.0
```

### [bsd-2-clause](generator.js#L78)

Generate a BSD 2-clause "Simplified" License `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:bsd-2-clause
$ gen license:bsd-2-clause --dest ./docs
$ gen dest license:bsd-2-clause
```

### [bsd-3-clause](generator.js#L95)

Generate a BSD 3-clause "New" or "Revised" License `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:bsd-3-clause
$ gen license:bsd-3-clause --dest ./docs
$ gen dest license:bsd-3-clause
```

### [cc0-1.0](generator.js#L112)

Generate a Creative Commons Zero v1.0 Universal `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:cc0-1.0
$ gen license:cc0-1.0 --dest ./docs
$ gen dest license:cc0-1.0
```

### [epl-1.0](generator.js#L129)

Generate an Eclipse Public License 1.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:epl-1.0
$ gen license:epl-1.0 --dest ./docs
$ gen dest license:epl-1.0
```

### [gpl-2.0](generator.js#L146)

Generate a GNU General Public License v2.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:gpl-2.0
$ gen license:gpl-2.0 --dest ./docs
$ gen dest license:gpl-2.0
```

### [gpl-3.0](generator.js#L163)

Generate a GNU General Public License v3.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:gpl-3.0
$ gen license:gpl-3.0 --dest ./docs
$ gen dest license:gpl-3.0
```

### [isc](generator.js#L180)

Generate a ISC License `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:isc
$ gen license:isc --dest ./docs
$ gen dest license:isc
```

### [lgpl-2.1](generator.js#L197)

Generate a GNU Lesser General Public License v2.1 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:lgpl-2.1
$ gen license:lgpl-2.1 --dest ./docs
$ gen dest license:lgpl-2.1
```

### [lgpl-3.0](generator.js#L217)

Generate a GNU Lesser General Public License v3.0 `LICENSE.lesser` file in the current working directory.

This will also generate a GNU General Public License v3.0 `LICENSE`
file in the current working directory.

**Example**

```sh
$ gen license:lgpl-3.0
$ gen license:lgpl-3.0 --dest ./docs
$ gen dest license:lgpl-3.0
```

### [mit](generator.js#L234)

Generate a MIT License `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:mit
$ gen license:mit --dest ./docs
$ gen dest license:mit
```

### [mpl-2.0](generator.js#L251)

Generate a Mozilla Public License 2.0 `LICENSE` file in the current working directory.

**Example**

```sh
$ gen license:mpl-2.0
$ gen license:mpl-2.0 --dest ./docs
$ gen dest license:mpl-2.0
```

### [unlicense](generator.js#L268)

Generate a The Unlicense `UNLICENSE` file in the current working directory.

**Example**

```sh
$ gen license:unlicense
$ gen license:unlicense --dest ./docs
$ gen dest license:unlicense
```

### [license](generator.js#L290)

Prompts the user to choose the template to use for generating a `LICENSE` file in the current working directory. This task is also aliased as `choose-license` to provide a semantic name for API usage (e.g. `app.generate('choose-license', cb)`).

**Example**

```sh
$ gen license
$ gen license --dest ./docs
$ gen dest license
# or
$ gen license:choose
$ gen license:choose --dest ./docs
$ gen dest license:choose
```

### [default](generator.js#L331)

Alias for the [license](#license) task, to allow this generator to be run with the following command:

**Example**

```sh
$ gen license
```

Visit Generate's [documentation for tasks](https://github.com/generate/generate/blob/master/docs/tasks.md).

## API usage

Use `generate-license` as a [plugin](https://github.com/generate/generate/blob/master/docs/plugins.md) in your own [generator](https://github.com/generate/generate/blob/master/docs/generators.md).

### Install locally

Install with [npm](https://www.npmjs.com/):

```sh
$ npm install --save generate-license
```

### Use as a plugin

When used as a plugin, tasks from `generate-license` are added to your generator's instance.

```js
module.exports = function(app) {
  app.use(require('generate-license'));
  // do generator stuff
};
```

**Running tasks**

You can now run any tasks from `generate-license` as if they were part of your own generator.

```js
module.exports = function(app) {
  app.use(require('generate-license'));

  app.task('foo', function(cb) {
    // do task stuff
    cb();
  });

  // run the `mit` task from `generate-license`
  app.task('default', ['foo', 'mit']);
};
```

### Register as a generator

When registered as a generator, tasks from `generate-license` are added to the "namespace" you give to the generator.

```js
module.exports = function(app) {
  app.register('foo', require('generate-license'));
  // generate
};
```

**Running tasks**

Pass the names of one or more tasks to run to the `.generate` method, prefixed with the namespace of the sub-generator (`foo`, in our example):

**Examples**

Run the [mit](#mit) task from `generate-license`:

```js
module.exports = function(app) {
  app.register('foo', require('generate-license'));

  app.generate('foo:mit', function(err) {
    if (err) console.log(err);
  });
};
```

Wrap the call to `.generate` in a task, so it can be called on demand:

```js
module.exports = function(app) {
  app.register('foo', require('generate-license'));

  app.task('mit-license', function(cb) {
    app.generate('foo:mit', cb);
  });
};
```

**More information**

Visit the [generator docs](https://github.com/generate/generate/blob/master/docs/generators.md) to learn more about creating, installing, using and publishing generators.

## Customization

### Destination directory

To customize the destination directory, install [generate-dest](https://github.com/generate/generate-dest) globally, then in the command line prefix `dest` before any other generator names.

For example, the following will prompt you for the destination path to use, then pass the result to `generate-license`:

```sh
$ gen dest license
```

### Overriding templates

You can override a template by adding a template of the same name to the `templates` directory in user home.

For example, to override the `foo.tmpl` template, add a template at the following path `~/generate/templates/foo.tmpl`, where `~/` is the user-home directory that `os.homedir()` resolves to on your system.

## About

### Related projects

* [generate-eslint](https://www.npmjs.com/package/generate-eslint): Generate a new `.eslintrc.json` or `.eslintignore` file from a pre-defined or user-defined template. Can be… [more](https://github.com/generate/generate-eslint) | [homepage](https://github.com/generate/generate-eslint "Generate a new `.eslintrc.json` or `.eslintignore` file from a pre-defined or user-defined template. Can be used from the command line when installed globally, or as a plugin in your own generator.")
* [generate-install](https://www.npmjs.com/package/generate-install): Generator that automatically detects the dependencies or devDependencies to install based on the templates or… [more](https://github.com/generate/generate-install) | [homepage](https://github.com/generate/generate-install "Generator that automatically detects the dependencies or devDependencies to install based on the templates or includes that are dynamically used by your generator. This can be used as a sub-generator or plugin in your own generator.")
* [generate-package](https://www.npmjs.com/package/generate-package): Generate] a package.json from a pre-defined or user-defined template. This generator can be used from… [more](https://github.com/generate/generate-package) | [homepage](https://github.com/generate/generate-package "[Generate] a package.json from a pre-defined or user-defined template. This generator can be used from the command line when globally installed, or as a plugin or sub-generator in your own generator.")

### Contributing

Pull requests and stars are always welcome. For bugs and feature requests, [please create an issue](../../issues/new).

### Running tests

Install dev dependencies:

```sh
$ npm install -d && npm test
```

### Author

**Jon Schlinkert**

* [github/jonschlinkert](https://github.com/jonschlinkert)
* [twitter/jonschlinkert](http://twitter.com/jonschlinkert)

### License

Copyright © 2016, [Jon Schlinkert](https://github.com/jonschlinkert).
Released under the [MIT license](https://github.com/generate/generate-license/blob/master/LICENSE).

***

_This file was generated by [verb-generate-readme](https://github.com/verbose/verb-generate-readme), v0.1.29, on August 09, 2016._